==> opize-design-system-1.4.7.tgz: package/src/components/Date/Date.style.tsx <==
import { styled } from 'styled-components';
import { cv } from '../..';

export interface StyledDateOuterContainerProps {
    $width: string;
}
export const StyledDateOuterContainer = styled.div<StyledDateOuterContainerProps>`
    display: flex;
    flex-direction: column;
    width: ${(props) => props.$width};
    gap: 6px;
`;

export const StyledDateLabel = styled.div`
    color: ${cv.default600};
    font-size: 12px;
`;

const getSizeStyle = ({ $size }: StyledDateContainerProps) => {
    switch ($size) {
        case 'small':
            return `
                font-size: ${cv.formFontSizeSmall};
                height: ${cv.formHeightSmall};
                border-radius: ${cv.formBorderRadiusSmall}
            `;
        case 'regular':
            return `
                font-size: ${cv.formFontSizeRegular};
                height: ${cv.formHeightRegular};
                border-radius: ${cv.formBorderRadiusRegular}
            `;
        case 'medium':
            return `
            font-size: ${cv.formFontSizeMedium};
                height: ${cv.formHeightMedium};
                border-radius: ${cv.formBorderRadiusMedium}
            `;
        case 'large':
            return `
                font-size: ${cv.formFontSizeLarge};
                height: ${cv.formHeightLarge};
                border-radius: ${cv.formBorderRadiusLarge}
            `;
    }
};
export interface StyledDateContainerProps {
    $size: 'small' | 'regular' | 'medium' | 'large';
    $disabled: boolean;
    $readOnly: boolean;
    $width: string;
    $isError: boolean;
}

export const StyledDateContainer = styled.div<StyledDateContainerProps>`
    display: flex;
    align-items: center;
    transition: 200ms;
    border: solid 1px ${(props) => (props.$isError ? cv.red : cv.default200)};
    background-color: ${(props) =>
        props.$disabled || props.$readOnly ? cv.default100 : cv.background};
    width: ${(props) => props.$width || '100%'};

    ${(props) => getSizeStyle(props)};

    &:focus-within {
        ${(props) =>
            props.$disabled || props.$readOnly
                ? ''
                : `
            border: solid 1px ${cv.default400};
            background-color: ${cv.background};
        `}
    }
`;

export interface StyledDateProps {
    $size: 'small' | 'regular' | 'medium' | 'large';
}

const getDateSizeStyle = ({ $size }: StyledDateProps) => {
    switch ($size) {
        case 'small':
            return `
                padding: 0px 8px;
            `;
        case 'regular':
            return `
                padding: 0px 10px;
            `;
        case 'medium':
            return `
                padding: 0px 12px;
            `;
        case 'large':
            return `
                padding: 0px 16px;
            `;
    }
};

export const StyledDate = styled.input<StyledDateProps>`
    cursor: auto;
    display: flex;
    align-items: center;
    justify-content: flex-start;
    width: 100%;
    height: 100%;
    border: none;
    outline: none;
    background-color: transparent;
    transition: 200ms;

    ${(props) => getDateSizeStyle(props)};

    &::placeholder {
        color: ${cv.default400};
    }

    &:disabled {
        color: ${cv.default600};
        cursor: not-allowed;
        &::placeholder {
            color: ${cv.default400};
        }
    }

    &:read-only {
        color: ${cv.default600};
        &::placeholder {
            color: ${cv.default400};
        }
    }

    &:focus-within {
        outline: none;
    }

    &::-webkit-datetime-edit-ampm-field,
    &::-webkit-datetime-edit-day-field,
    &::-webkit-datetime-edit-hour-field,
    &::-webkit-datetime-edit-millisecond-field,
    &::-webkit-datetime-edit-minute-field,
    &::-webkit-datetime-edit-month-field,
    &::-webkit-datetime-edit-second-field,
    &::-webkit-datetime-edit-week-field,
    &::-webkit-datetime-edit-year-field {
        cursor: text;
    }

    &::-webkit-calendar-picker-indicator {
        stroke: ${cv.foreground};
        cursor: pointer;
    }
`;

==> opize-design-system-1.5.0.tgz: package/src/components/Date/Date.style.tsx <==
import { styled } from 'styled-components';
import { cv, typos } from '../..';

export interface StyledDateOuterContainerProps {
    $width: string;
}
export const StyledDateOuterContainer = styled.div<StyledDateOuterContainerProps>`
    display: flex;
    flex-direction: column;
    width: ${(props) => props.$width};
    gap: 4px;
`;

export const StyledDateLabel = styled.div`
    ${typos.label};
`;

const getSizeStyle = ({ $size }: StyledDateContainerProps) => {
    switch ($size) {
        case 'small':
            return `
                font-size: ${cv.var.inputSmFontSize};
                height: ${cv.var.inputSmHeight};
                border-radius: ${cv.var.inputSmRound}
            `;
        case 'regular':
            return `
                font-size: ${cv.var.inputRgFontSize};
                height: ${cv.var.inputRgHeight};
                border-radius: ${cv.var.inputRgRound}
            `;
        case 'medium':
            return `
            font-size: ${cv.var.inputMdFontSize};
                height: ${cv.var.inputMdHeight};
                border-radius: ${cv.var.inputMdRound}
            `;
    }
};
export interface StyledDateContainerProps {
    $size: 'small' | 'regular' | 'medium';
    $disabled: boolean;
    $variant: 'primary' | 'secondary';
    $readOnly: boolean;
    $width: string;
    $isError: boolean;
}

export const StyledDateContainer = styled.div<StyledDateContainerProps>`
    display: flex;
    align-items: center;
    transition: 200ms;
    border: solid 1px
        ${(props) =>
            props.$isError
                ? cv.statusRed
                : props.$variant === 'primary'
                ? cv.border
                : 'transparent'};
    background-color: ${(props) =>
        props.$disabled || props.$readOnly ? cv.gray100 : cv.background};
    width: ${(props) => props.$width || '100%'};

    ${(props) => getSizeStyle(props)};

    &:hover {
        ${(props) =>
            props.$disabled || props.$readOnly
                ? ''
                : `
            border: solid 1px ${cv.border};
        `}
    }

    &:focus-within {
        ${(props) =>
            props.$disabled || props.$readOnly
                ? ''
                : `
            border: solid 1px ${cv.gray100};
            background-color: ${cv.gray100};
        `}
    }
`;

export interface StyledDateProps {
    $size: 'small' | 'regular' | 'medium';
}

const getDateSizeStyle = ({ $size }: StyledDateProps) => {
    switch ($size) {
        case 'small':
            return `
                padding: ${cv.var.inputSmPadding};
            `;
        case 'regular':
            return `
                padding: ${cv.var.inputRgPadding};
            `;
        case 'medium':
            return `
                padding: ${cv.var.inputMdPadding};
            `;
    }
};

export const StyledDate = styled.input<StyledDateProps>`
    cursor: auto;
    display: flex;
    align-items: center;
    justify-content: flex-start;
    width: 100%;
    height: 100%;
    border: none;
    outline: none;
    background-color: transparent;
    transition: 200ms;

    ${typos.input};
    ${(props) => getDateSizeStyle(props)};

    &::placeholder {
        color: ${cv.placeholder};
    }

    &:disabled {
        color: ${cv.gray500};
        cursor: not-allowed;
        &::placeholder {
            color: ${cv.placeholder};
        }
    }

    &:read-only {
        color: ${cv.gray500};
        &::placeholder {
            color: ${cv.placeholder};
        }
    }

    &:focus-within {
        outline: none;
    }

    &::-webkit-datetime-edit-ampm-field,
    &::-webkit-datetime-edit-day-field,
    &::-webkit-datetime-edit-hour-field,
    &::-webkit-datetime-edit-millisecond-field,
    &::-webkit-datetime-edit-minute-field,
    &::-webkit-datetime-edit-month-field,
    &::-webkit-datetime-edit-second-field,
    &::-webkit-datetime-edit-week-field,
    &::-webkit-datetime-edit-year-field {
        cursor: text;
    }

    &::-webkit-calendar-picker-indicator {
        stroke: ${cv.text};
        cursor: pointer;
    }
`;
